yakumo.base.SubManager

Package yakumo :: Module base :: Class SubManager |
[hide private]
[frames] | no frames]

# Class SubManager

source code

    object --+
             |
       Manager --+
                 |
                SubManager

Known Subclasses:
  - GlanceV2SubManager
  - , neutron.v2.security_group_rule.Manager
  - , neutron.v2.lb.vip.Manager
  - , neutron.v2.lb.member.Manager
  - , neutron.v2.lbaas.listener.Manager
  - , neutron.v2.lbaas.member.Manager
  - , nova.v2.interface_attachment.Manager
  - , nova.v2.security_group_rule.Manager
  - , nova.v2.volume_attachment.Manager

Base class for sub resource managers.

Instance Methods | [hide private]
yakumo.base.Manager |
__init__(self, parent_resource, *args, **kwargs) Create a Manager object | source code
Inherited from `Manager`: `create`, `find`, `find_one`, `get`, `get_empty`, `list` Inherited from `Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `Manager`: `resource_class`, `service_type` Inherited from `Manager` (private): `_attr_mapping`, `_has_detail`, `_has_extra_attr`, `_hidden_methods`, `_id_attr`, `_json_resource_key`, `_json_resources_key`, `_update_method`, `_url_resource_list_path`, `_url_resource_path`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, parent_resource, *args, **kwargs) (Constructor) | source code
Create a Manager object kwargs: options Parameters: `client` - client object `verbose` - Whether str(Resource) displays all attributes Returns: yakumo.base.Manager Manager object Overrides: object.__init__ (inherited documentation)